@@ -3,6 +3,7 @@ import typing as t
 from fastapi import Request, Response, __version__
 
 from debug_toolbar.panels import Panel
+from debug_toolbar.types import Stats
 
 
 class VersionsPanel(Panel):
@@ -19,11 +20,7 @@ class VersionsPanel(Panel):
         scripts.append(self.url_for("debug_toolbar.static", path="js/versions.js"))
         return scripts
 
-    async def generate_stats(
-        self,
-        request: Request,
-        response: Response,
-    ) -> t.Optional[t.Dict[str, t.Any]]:
+    async def generate_stats(self, request: Request, response: Response) -> Stats:
         try:
             import pkg_resources
         except ImportError:
